import { type KeysOf, type PickFrom } from './../helpers/composables.js';
import type { FetchOptions } from 'ofetch';
import { type Ref } from 'vue';
import { type GraphqlClientContext } from '#nuxt-graphql-middleware/client-options';
import type { GraphqlResponse } from '#nuxt-graphql-middleware/response';
import type { RequestCacheOptions } from './../types.js';
import type { AsyncData, AsyncDataOptions, NuxtError } from '#app';
import type { DefaultAsyncDataValue } from 'nuxt/app/defaults';
import type { Query } from '#nuxt-graphql-middleware/operation-types';
type AsyncGraphqlQueryOptions<FetchOptions, ResT, DataT = ResT, PickKeys extends KeysOf<DataT> = KeysOf<DataT>, DefaultT = DefaultAsyncDataValue> = AsyncDataOptions<ResT, DataT, PickKeys, DefaultT> & {
    /**
     * Control how the GraphQL response can be cached.
     */
    graphqlCaching?: RequestCacheOptions;
    /**
     * Options for the fetch call to the GraphQL middleware endpoint.
     */
    fetchOptions?: FetchOptions;
    /**
     * Additional client context.
     *
     * These values override the values defined globally in defineGraphqlClientOptions().
     */
    clientContext?: Partial<GraphqlClientContext>;
};
export declare function useAsyncGraphqlQuery<Name extends keyof Query, Operation extends Query[Name] = Query[Name], ResT extends GraphqlResponse<Operation['response']> = GraphqlResponse<Operation['response']>, FetchO extends FetchOptions<'json'> = FetchOptions<'json'>, VarType extends Operation['variables'] = Operation['variables'], NuxtErrorDataT = unknown, DataT = ResT, DefaultT = undefined, PickKeys extends KeysOf<DataT> = KeysOf<DataT>>(name: Name, ...args: Operation['needsVariables'] extends false ? [
    (undefined | null | Record<string, never> | VarType | Ref<VarType>)?,
    AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>?
] : [
    VarType | Ref<VarType>,
    (undefined | null | AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>)?
]): AsyncData<PickFrom<DataT, PickKeys> | DefaultT, (NuxtErrorDataT extends Error | NuxtError ? NuxtErrorDataT : NuxtError<NuxtErrorDataT>) | undefined>;
export declare function useAsyncGraphqlQuery<Name extends keyof Query, Operation extends Query[Name] = Query[Name], ResT extends GraphqlResponse<Operation['response']> = GraphqlResponse<Operation['response']>, FetchO extends FetchOptions<'json'> = FetchOptions<'json'>, VarType extends Operation['variables'] = Operation['variables'], NuxtErrorDataT = unknown, DataT = ResT, DefaultT = DataT, PickKeys extends KeysOf<DataT> = KeysOf<DataT>>(name: Name, ...args: Operation['needsVariables'] extends false ? [
    (undefined | null | Record<string, never> | VarType | Ref<VarType>)?,
    AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>?
] : [
    VarType | Ref<VarType>,
    (undefined | null | AsyncGraphqlQueryOptions<FetchO, ResT, DataT, PickKeys, DefaultT>)?
]): AsyncData<PickFrom<DataT, PickKeys> | DefaultT, (NuxtErrorDataT extends Error | NuxtError ? NuxtErrorDataT : NuxtError<NuxtErrorDataT>) | undefined>;
export {};
