import { createError } from "h3";
import {
  CLIENT_CONTEXT_PREFIX
} from "./../../settings/index.js";
import { documents } from "#nuxt-graphql-middleware/documents";
export function isValidMutation(v) {
  return !!v && Object.hasOwn(documents.mutation, v);
}
export function isValidQuery(v) {
  return !!v && Object.hasOwn(documents.query, v);
}
export function queryParamToVariables(query) {
  try {
    if (query.__variables && typeof query.__variables === "string") {
      return JSON.parse(query.__variables);
    }
  } catch {
  }
  return query;
}
export function extractRequestContext(query) {
  const client = {};
  for (const property in query) {
    if (property.startsWith(CLIENT_CONTEXT_PREFIX)) {
      const value = query[property];
      if (typeof value === "string") {
        const key = property.replace(CLIENT_CONTEXT_PREFIX, "");
        client[key] = value;
      }
    }
  }
  return {
    client
  };
}
export function getEndpoint(config, serverOptions, event, operation, operationName, context) {
  if (serverOptions.graphqlEndpoint) {
    const result = serverOptions.graphqlEndpoint(
      event,
      operation,
      operationName,
      context
    );
    if (result) {
      return Promise.resolve(result);
    }
  }
  if (config.graphqlEndpoint) {
    return config.graphqlEndpoint;
  }
  throw new Error("Failed to determine endpoint for GraphQL server.");
}
export function getFetchOptions(serverOptions, event, operation, operationName, context) {
  if (serverOptions.serverFetchOptions) {
    return serverOptions.serverFetchOptions(
      event,
      operation,
      operationName,
      context
    ) || {};
  }
  return {};
}
export function throwError(statusMessage, statusCode = 400) {
  throw createError({
    statusCode,
    statusMessage
  });
}
export function onServerResponse(serverOptions, event, response, operation, operationName, context) {
  if (serverOptions.onServerResponse) {
    return serverOptions.onServerResponse(
      event,
      response,
      operation,
      operationName,
      context
    );
  }
  return response._data;
}
export function onServerError(serverOptions, event, error, operation, operationName, context) {
  if (serverOptions.onServerError) {
    return serverOptions.onServerError(
      event,
      error,
      operation,
      operationName,
      context
    );
  }
  const message = error && "message" in error ? error.message : "";
  throw createError({
    statusCode: 500,
    statusMessage: "Couldn't execute GraphQL query: " + message,
    data: error && "message" in error ? error.message : error
  });
}
