import { serverOptions } from "#nuxt-graphql-middleware/server-options";
import { useRuntimeConfig } from "#imports";
import { useEvent } from "nitropack/runtime";
import {
  getEndpoint,
  getFetchOptions,
  onServerError,
  onServerResponse
} from "../helpers/index.js";
export async function doGraphqlRequest(body, context = null, providedEvent = null) {
  const operationName = body.operationName || null;
  const event = providedEvent ?? useEvent();
  const runtimeConfig = useRuntimeConfig().graphqlMiddleware;
  if (serverOptions.doGraphqlRequest) {
    return serverOptions.doGraphqlRequest({
      event,
      operation: body.operation,
      operationName: body.operationName,
      operationDocument: body.query,
      variables: body.variables || {},
      context: context || {}
    });
  }
  const endpoint = await getEndpoint(
    runtimeConfig,
    serverOptions,
    event,
    null,
    operationName,
    context || null
  );
  const fetchOptions = await getFetchOptions(
    serverOptions,
    event,
    null,
    body.operationName || null,
    context
  );
  return $fetch.raw(endpoint, {
    // @ts-expect-error Not yet been fixed in nitro.
    method: "POST",
    body: {
      query: body.query,
      variables: body.variables,
      operationName: body.operationName
    },
    ...fetchOptions
  }).then((response) => {
    return onServerResponse(
      serverOptions,
      event,
      response,
      null,
      operationName,
      context
    );
  }).catch((error) => {
    return onServerError(
      serverOptions,
      event,
      error,
      null,
      operationName,
      context
    );
  });
}
